agentle.agents.errors.max\_tool\_calls\_exceeded\_error
=======================================================

.. automodule:: agentle.agents.errors.max_tool_calls_exceeded_error

   
   .. rubric:: Exceptions

   .. autosummary::
   
      MaxToolCallsExceededError
   